@@ -15,10 +15,9 @@
 import os
 import os.path
 import textwrap
-import time
+from unittest import mock
 
 import ddt
-import mock
 from oslo_concurrency import processutils as putils
 from oslo_log import log as logging
 
@@ -103,7 +102,7 @@ class LinuxSCSITestCase(base.TestCase):
         expected_commands = [('tee -a /sys/block/sdc/device/delete')]
         self.assertEqual(expected_commands, self.cmds)
 
-    @mock.patch('time.sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     @mock.patch('os.path.exists', return_value=True)
     def test_wait_for_volumes_removal_failure(self, exists_mock, sleep_mock):
         retries = 61
@@ -114,7 +113,7 @@ class LinuxSCSITestCase(base.TestCase):
                                       for name in names] * retries)
         self.assertEqual(retries - 1, sleep_mock.call_count)
 
-    @mock.patch('time.sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     @mock.patch('os.path.exists', side_effect=(True, True, False, False))
     def test_wait_for_volumes_removal_retry(self, exists_mock, sleep_mock):
         names = ('sda', 'sdb')
@@ -195,7 +194,7 @@ class LinuxSCSITestCase(base.TestCase):
         expected_path = '/dev/disk/by-id/dm-uuid-mpath-%s' % fake_wwn
         self.assertEqual(expected_path, found_path)
 
-    @mock.patch('time.sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     @mock.patch.object(os.path, 'exists')
     def test_find_multipath_device_path_mapper(self, exists_mock, sleep_mock):
         # the wait loop tries 3 times before it gives up
@@ -211,14 +210,14 @@ class LinuxSCSITestCase(base.TestCase):
         self.assertTrue(sleep_mock.called)
 
     @mock.patch.object(os.path, 'exists', return_value=False)
-    @mock.patch.object(time, 'sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     def test_find_multipath_device_path_fail(self, exists_mock, sleep_mock):
         fake_wwn = '1234567890'
         found_path = self.linuxscsi.find_multipath_device_path(fake_wwn)
         self.assertIsNone(found_path)
 
     @mock.patch.object(os.path, 'exists', return_value=False)
-    @mock.patch.object(time, 'sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     def test_wait_for_path_not_found(self, exists_mock, sleep_mock):
         path = "/dev/disk/by-id/dm-uuid-mpath-%s" % '1234567890'
         self.assertRaisesRegex(exception.VolumeDeviceNotFound,
@@ -246,6 +245,7 @@ class LinuxSCSITestCase(base.TestCase):
         devices_names = ('sda', 'sdb')
         exc = exception.ExceptionChainer()
         mp_name = self.linuxscsi.remove_connection(devices_names,
+                                                   is_multipath=True,
                                                    force=mock.sentinel.Force,
                                                    exc=exc)
         find_dm_mock.assert_called_once_with(devices_names)
@@ -275,7 +275,8 @@ class LinuxSCSITestCase(base.TestCase):
         exc = exception.ExceptionChainer()
         self.assertRaises(exception.ExceptionChainer,
                           self.linuxscsi.remove_connection,
-                          devices_names, force=False, exc=exc)
+                          devices_names, is_multipath=True,
+                          force=False, exc=exc)
         find_dm_mock.assert_called_once_with(devices_names)
         get_dm_name_mock.assert_called_once_with(find_dm_mock.return_value)
         flush_mp_mock.assert_called_once_with(get_dm_name_mock.return_value)
@@ -284,49 +285,36 @@ class LinuxSCSITestCase(base.TestCase):
         remove_link_mock.assert_not_called()
         self.assertTrue(bool(exc))
 
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'find_sysfs_multipath_dm')
     @mock.patch.object(linuxscsi.LinuxSCSI, '_remove_scsi_symlinks')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'wait_for_volumes_removal')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'remove_scsi_device')
-    def test_remove_connection_singlepath_no_path(self, remove_mock, wait_mock,
-                                                  remove_link_mock,
-                                                  find_dm_mock):
-        # Test remove connection when we didn't form a multipath and didn't
-        # even use any of the devices that were found.  This means that we
-        # don't flush any of the single paths when removing them.
-        find_dm_mock.return_value = None
+    def test_remove_connection_singlepath(self, remove_mock, wait_mock,
+                                          remove_link_mock):
         devices_names = ('sda', 'sdb')
         exc = exception.ExceptionChainer()
-        self.linuxscsi.remove_connection(devices_names,
+        self.linuxscsi.remove_connection(devices_names, is_multipath=False,
                                          force=mock.sentinel.Force,
                                          exc=exc)
-        find_dm_mock.assert_called_once_with(devices_names)
         remove_mock.assert_has_calls(
             [mock.call('/dev/sda', mock.sentinel.Force, exc, False),
              mock.call('/dev/sdb', mock.sentinel.Force, exc, False)])
         wait_mock.assert_called_once_with(devices_names)
         remove_link_mock.assert_called_once_with(devices_names)
 
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'find_sysfs_multipath_dm')
     @mock.patch.object(linuxscsi.LinuxSCSI, '_remove_scsi_symlinks')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'wait_for_volumes_removal')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'remove_scsi_device')
     def test_remove_connection_singlepath_used(self, remove_mock, wait_mock,
-                                               remove_link_mock, find_dm_mock):
-        # Test remove connection when we didn't form a multipath and just used
-        # one of the single paths that were found.  This means that we don't
-        # flush any of the single paths when removing them.
-        find_dm_mock.return_value = None
+                                               remove_link_mock):
         devices_names = ('sda', 'sdb')
         exc = exception.ExceptionChainer()
 
         # realpath was mocked on test setup
         with mock.patch('os.path.realpath', side_effect=self.realpath):
-            self.linuxscsi.remove_connection(devices_names,
+            self.linuxscsi.remove_connection(devices_names, is_multipath=True,
                                              force=mock.sentinel.Force,
                                              exc=exc, path_used='/dev/sdb',
                                              was_multipath=False)
-        find_dm_mock.assert_called_once_with(devices_names)
         remove_mock.assert_has_calls(
             [mock.call('/dev/sda', mock.sentinel.Force, exc, False),
              mock.call('/dev/sdb', mock.sentinel.Force, exc, True)])
@@ -501,7 +489,7 @@ class LinuxSCSITestCase(base.TestCase):
         self.assertEqual("1", info['devices'][1]['id'])
         self.assertEqual("9", info['devices'][1]['lun'])
 
-    @mock.patch.object(time, 'sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     def test_wait_for_rw(self, mock_sleep):
         lsblk_output = """3624a93709a738ed78583fd1200143029 (dm-2)  0
 sdb                                       0
@@ -543,7 +531,7 @@ loop0                                     0"""
         self.linuxscsi.wait_for_rw(wwn, path)
         self.assertFalse(mock_sleep.called)
 
-    @mock.patch.object(time, 'sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     def test_wait_for_rw_needs_retry(self, mock_sleep):
         lsblk_ro_output = """3624a93709a738ed78583fd1200143029 (dm-2)  0
 sdb                                       0
@@ -613,7 +601,7 @@ loop0                                     0"""
         self.linuxscsi.wait_for_rw(wwn, path)
         self.assertEqual(1, mock_sleep.call_count)
 
-    @mock.patch.object(time, 'sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     def test_wait_for_rw_always_readonly(self, mock_sleep):
         lsblk_output = """3624a93709a738ed78583fd1200143029 (dm-2)  0
 sdb                                       0
@@ -874,16 +862,6 @@ loop0                                     0"""
                                     'id': '0',
                                     'lun': '0'})
 
-    @mock.patch('six.moves.builtins.open')
-    def test_get_sysfs_wwn_mpath(self, open_mock):
-        wwn = '3600d0230000000000e13955cc3757800'
-        cm_open = open_mock.return_value.__enter__.return_value
-        cm_open.read.return_value = 'mpath-' + wwn
-
-        res = self.linuxscsi.get_sysfs_wwn(mock.sentinel.device_names, 'dm-1')
-        open_mock.assert_called_once_with('/sys/block/dm-1/dm/uuid')
-        self.assertEqual(wwn, res)
-
     @mock.patch('glob.glob')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'get_sysfs_wwid')
     def test_get_sysfs_wwn_single_designator(self, get_wwid_mock, glob_mock):
@@ -895,67 +873,25 @@ loop0                                     0"""
         glob_mock.assert_called_once_with('/dev/disk/by-id/scsi-*')
         get_wwid_mock.assert_called_once_with(mock.sentinel.device_names)
 
-    @mock.patch('six.moves.builtins.open', side_effect=Exception)
-    @mock.patch('glob.glob')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'get_sysfs_wwid')
-    def test_get_sysfs_wwn_mpath_exc(self, get_wwid_mock, glob_mock,
-                                     open_mock):
-        glob_mock.return_value = ['/dev/disk/by-id/scsi-wwid1',
-                                  '/dev/disk/by-id/scsi-wwid2']
-        get_wwid_mock.return_value = 'wwid1'
-        res = self.linuxscsi.get_sysfs_wwn(mock.sentinel.device_names, 'dm-1')
-        open_mock.assert_called_once_with('/sys/block/dm-1/dm/uuid')
-        self.assertEqual('wwid1', res)
-        glob_mock.assert_called_once_with('/dev/disk/by-id/scsi-*')
-        get_wwid_mock.assert_called_once_with(mock.sentinel.device_names)
-
-    @mock.patch('os.listdir', return_value=['sda', 'sdd'])
     @mock.patch('os.path.realpath', side_effect=('/other/path',
-                                                 '/dev/dm-5',
                                                  '/dev/sda', '/dev/sdb'))
-    @mock.patch('os.path.islink', side_effect=(False,) + (True,) * 5)
-    @mock.patch('os.stat', side_effect=(False,) + (True,) * 4)
+    @mock.patch('os.path.islink', side_effect=(False, True, True, True, True))
+    @mock.patch('os.stat', side_effect=(False, True, True, True))
     @mock.patch('glob.glob')
     @mock.patch.object(linuxscsi.LinuxSCSI, 'get_sysfs_wwid')
     def test_get_sysfs_wwn_multiple_designators(self, get_wwid_mock, glob_mock,
                                                 stat_mock, islink_mock,
-                                                realpath_mock, listdir_mock):
+                                                realpath_mock):
         glob_mock.return_value = ['/dev/disk/by-id/scsi-fail-link',
                                   '/dev/disk/by-id/scsi-fail-stat',
                                   '/dev/disk/by-id/scsi-non-dev',
-                                  '/dev/disk/by-id/scsi-another-dm',
                                   '/dev/disk/by-id/scsi-wwid1',
                                   '/dev/disk/by-id/scsi-wwid2']
-
         get_wwid_mock.return_value = 'pre-wwid'
         devices = ['sdb', 'sdc']
         res = self.linuxscsi.get_sysfs_wwn(devices)
         self.assertEqual('wwid2', res)
         glob_mock.assert_called_once_with('/dev/disk/by-id/scsi-*')
-        listdir_mock.assert_called_once_with('/sys/class/block/dm-5/slaves')
-        get_wwid_mock.assert_called_once_with(devices)
-
-    @mock.patch('os.listdir', side_effect=[['sda', 'sdb'], ['sdc', 'sdd']])
-    @mock.patch('os.path.realpath', side_effect=('/dev/sde',
-                                                 '/dev/dm-5',
-                                                 '/dev/dm-6'))
-    @mock.patch('os.path.islink', mock.Mock())
-    @mock.patch('os.stat', mock.Mock())
-    @mock.patch('glob.glob')
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'get_sysfs_wwid', return_value='')
-    def test_get_sysfs_wwn_dm_link(self, get_wwid_mock, glob_mock,
-                                   realpath_mock, listdir_mock):
-        glob_mock.return_value = ['/dev/disk/by-id/scsi-wwid1',
-                                  '/dev/disk/by-id/scsi-another-dm',
-                                  '/dev/disk/by-id/scsi-our-dm']
-
-        devices = ['sdc', 'sdd']
-        res = self.linuxscsi.get_sysfs_wwn(devices)
-        self.assertEqual('our-dm', res)
-        glob_mock.assert_called_once_with('/dev/disk/by-id/scsi-*')
-        listdir_mock.assert_has_calls(
-            [mock.call('/sys/class/block/dm-5/slaves'),
-             mock.call('/sys/class/block/dm-6/slaves')])
         get_wwid_mock.assert_called_once_with(devices)
 
     @mock.patch('os.path.realpath', side_effect=('/dev/sda', '/dev/sdb'))
@@ -974,16 +910,6 @@ loop0                                     0"""
         glob_mock.assert_called_once_with('/dev/disk/by-id/scsi-*')
         get_wwid_mock.assert_called_once_with(devices)
 
-    @mock.patch('glob.glob', return_value=[])
-    @mock.patch.object(linuxscsi.LinuxSCSI, 'get_sysfs_wwid')
-    def test_get_sysfs_wwn_no_links(self, get_wwid_mock, glob_mock):
-        get_wwid_mock.return_value = ''
-        devices = ['sdc']
-        res = self.linuxscsi.get_sysfs_wwn(devices)
-        self.assertEqual('', res)
-        glob_mock.assert_called_once_with('/dev/disk/by-id/scsi-*')
-        get_wwid_mock.assert_called_once_with(devices)
-
     @ddt.data({'wwn_type': 't10.', 'num_val': '1'},
               {'wwn_type': 'eui.', 'num_val': '2'},
               {'wwn_type': 'naa.', 'num_val': '3'})
@@ -1152,15 +1078,8 @@ loop0                                     0"""
     def test_get_dev_path_no_path(self, con_props, dev_info):
         self.assertEqual('', self.linuxscsi.get_dev_path(con_props, dev_info))
 
-    @ddt.data(('/dev/sda', '/dev/sda', False, True, None),
-              # This checks that we ignore the was_multipath parameter if it
-              # doesn't make sense (because the used path is the one we are
-              # asking about)
-              ('/dev/sda', '/dev/sda', True, True, None),
+    @ddt.data(('/dev/sda', '/dev/sda', True, False, None),
               ('/dev/sda', '', True, False, None),
-              # Check for encrypted volume
-              ('/dev/link_sda', '/dev/disk/by-path/pci-XYZ', False, True,
-               ('/dev/sda', '/dev/mapper/crypt-pci-XYZ')),
               ('/dev/link_sda', '/dev/link_sdb', False, False, ('/dev/sda',
                                                                 '/dev/sdb')),
               ('/dev/link_sda', '/dev/link2_sda', False, True, ('/dev/sda',
